==> dxirc_1.30.0-1.tar.gz: BUILD/qt/dialogs/connectdialog.cpp <==
/*
 *      connectdialog.cpp
 *
 *      Copyright 2014 David Vachulka <arch_dvx@users.sourceforge.net>
 *
 *      This program is free software; you can redistribute it and/or modify
 *      it under the terms of the GNU General Public License as published by
 *      the Free Software Foundation; either version 3 of the License, or
 *      (at your option) any later version.
 *
 *      This program is distributed in the hope that it will be useful,
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of
 *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *      GNU General Public License for more details.
 *
 *      You should have received a copy of the GNU General Public License
 *      along with this program; if not, write to the Free Software
 *      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 *      MA 02110-1301, USA.
 */

#include <QSslSocket>
#include "connectdialog.h"
#include "config.h"
#include "i18n.h"
#include "dxutils.h"

ConnectDialog::ConnectDialog(QWidget *parent)
: QDialog(parent)
{
    QGridLayout *matrix = new QGridLayout;
    int i = 0;
    matrix->addWidget(new QLabel(_("Hostname:")), i, 0);
#ifdef DEBUG
    m_hostname = new QLineEdit("localhost");
#else
    m_hostname = new QLineEdit("irc.freenode.net");
#endif
    matrix->addWidget(m_hostname, i, 1);
    i++;
    matrix->addWidget(new QLabel(_("Port:")), i, 0);
    m_port = new QSpinBox;
    m_port->setRange(0, 65536);
    m_port->setValue(6667);
    matrix->addWidget(m_port, i, 1);
    i++;
    matrix->addWidget(new QLabel(_("Password:")), i, 0);
    m_password = new QLineEdit;
    m_password->setEchoMode(QLineEdit::PasswordEchoOnEdit);
    matrix->addWidget(m_password, i, 1);
    i++;
    matrix->addWidget(new QLabel(_("Nickname:")), i, 0);
    m_nick = new QLineEdit(dxutils::getUsername());
    matrix->addWidget(m_nick, i, 1);
    i++;
    matrix->addWidget(new QLabel(_("Realname:")), i, 0);
    m_realname = new QLineEdit;
    matrix->addWidget(m_realname, i, 1);
    i++;
    matrix->addWidget(new QLabel(_("Channel(s):")), i, 0);
    m_channels = new QLineEdit;
    m_channels->setText("#");
    m_channels->setToolTip(_("Channels need to be comma separated"));
    matrix->addWidget(m_channels, i, 1);
    i++;
    m_ssl = new QCheckBox;
 #ifndef QT_NO_OPENSSL
    if(QSslSocket::supportsSsl())
    {
        matrix->addWidget(new QLabel(_("Use SSL:")), i, 0);
        matrix->addWidget(m_ssl, i, 1);
        i++;
    }
 #endif
    matrix->addWidget(new QLabel(_("Commands on connection:")), i, 0);
    m_commands = new QTextEdit;
    matrix->addWidget(m_commands, i, 1);
    QDialogButtonBox *buttons = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel);
    connect(buttons, SIGNAL(accepted()), this, SLOT(accept()));
    connect(buttons, SIGNAL(rejected()), this, SLOT(reject()));
    QVBoxLayout *mainFrame = new QVBoxLayout(this);
    mainFrame->addLayout(matrix);
    mainFrame->addWidget(buttons);
    setLayout(mainFrame);
    setWindowTitle(_("Quick connect"));
}

ServerInfo ConnectDialog::serverInfo() const
{
    ServerInfo s;
    s.hostname = m_hostname->text();
    s.port = m_port->value();
    s.passwd = m_password->text();
    s.nick = m_nick->text().isEmpty()?"xxx":m_nick->text();
    s.realname = m_realname->text();
    s.channels = m_channels->text();
#ifdef QT_NO_OPENSSL
    s.useSsl = false;
#else
    s.useSsl = QSslSocket::supportsSsl()?m_ssl->isChecked():false;
#endif
    s.commands = m_commands->toPlainText();
    s.autoConnect = false;
    return s;
}

==> dxirc_1.40.1-1.tar.gz: BUILD/qt/dialogs/connectdialog.cpp <==
/*
 *      connectdialog.cpp
 *
 *      Copyright 2014 David Vachulka <arch_dvx@users.sourceforge.net>
 *
 *      This program is free software; you can redistribute it and/or modify
 *      it under the terms of the GNU General Public License as published by
 *      the Free Software Foundation; either version 3 of the License, or
 *      (at your option) any later version.
 *
 *      This program is distributed in the hope that it will be useful,
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of
 *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *      GNU General Public License for more details.
 *
 *      You should have received a copy of the GNU General Public License
 *      along with this program; if not, write to the Free Software
 *      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 *      MA 02110-1301, USA.
 */

#include <QSslSocket>
#include "connectdialog.h"
#include "config.h"
#include "i18n.h"
#include "dxutils.h"

ConnectDialog::ConnectDialog(QWidget *parent)
: QDialog(parent)
{
    QGridLayout *matrix = new QGridLayout;
    int i = 0;
    matrix->addWidget(new QLabel(_("Hostname:")), i, 0);
#ifdef DEBUG
    m_hostname = new QLineEdit("localhost");
#else
    m_hostname = new QLineEdit("irc.libera.chat");
#endif
    matrix->addWidget(m_hostname, i, 1);
    i++;
    matrix->addWidget(new QLabel(_("Port:")), i, 0);
    m_port = new QSpinBox;
    m_port->setRange(0, 65536);
    m_port->setValue(6667);
    matrix->addWidget(m_port, i, 1);
    i++;
    matrix->addWidget(new QLabel(_("Password:")), i, 0);
    m_password = new QLineEdit;
    m_password->setEchoMode(QLineEdit::PasswordEchoOnEdit);
    matrix->addWidget(m_password, i, 1);
    i++;
    matrix->addWidget(new QLabel(_("Nickname:")), i, 0);
    m_nick = new QLineEdit(dxutils::getUsername());
    matrix->addWidget(m_nick, i, 1);
    i++;
    matrix->addWidget(new QLabel(_("Realname:")), i, 0);
    m_realname = new QLineEdit;
    matrix->addWidget(m_realname, i, 1);
    i++;
    matrix->addWidget(new QLabel(_("Channel(s):")), i, 0);
    m_channels = new QLineEdit;
    m_channels->setText("#");
    m_channels->setToolTip(_("Channels need to be comma separated"));
    matrix->addWidget(m_channels, i, 1);
    i++;
    m_ssl = new QCheckBox;
 #ifndef QT_NO_OPENSSL
    if(QSslSocket::supportsSsl())
    {
        matrix->addWidget(new QLabel(_("Use SSL:")), i, 0);
        matrix->addWidget(m_ssl, i, 1);
        i++;
    }
 #endif
    matrix->addWidget(new QLabel(_("Commands on connection:")), i, 0);
    m_commands = new QTextEdit;
    matrix->addWidget(m_commands, i, 1);
    QDialogButtonBox *buttons = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel);
    connect(buttons, SIGNAL(accepted()), this, SLOT(accept()));
    connect(buttons, SIGNAL(rejected()), this, SLOT(reject()));
    QVBoxLayout *mainFrame = new QVBoxLayout(this);
    mainFrame->addLayout(matrix);
    mainFrame->addWidget(buttons);
    setLayout(mainFrame);
    setWindowTitle(_("Quick connect"));
}

ServerInfo ConnectDialog::serverInfo() const
{
    ServerInfo s;
    s.hostname = m_hostname->text();
    s.port = m_port->value();
    s.passwd = m_password->text();
    s.nick = m_nick->text().isEmpty()?"xxx":m_nick->text();
    s.realname = m_realname->text();
    s.channels = m_channels->text();
#ifdef QT_NO_OPENSSL
    s.useSsl = false;
#else
    s.useSsl = QSslSocket::supportsSsl()?m_ssl->isChecked():false;
#endif
    s.commands = m_commands->toPlainText();
    s.autoConnect = false;
    return s;
}
